package main

import (
	"errors"
	"io/ioutil"
	"os"
	"path"
	"path/filepath"
	"strings"

	"gopkg.in/yaml.v3"
)

//
func GetPageData(directory string) (error, []pageData) {

	cleanedDirectory := path.Clean(directory)
	pageDataList := []pageData{}

	err := filepath.Walk(cleanedDirectory,
		func(current string, info os.FileInfo, err error) error {
			if err != nil {
				return err
			}

			cleanedPath := path.Clean(current)

			if !info.IsDir() {

				content, err := ioutil.ReadFile(cleanedPath)

				if err != nil {
					return err
				}

				err, p := importData(content)

				if err != nil {
					printError(cleanedPath + " does not contain a valid yaml definition")
					return nil
				}

				bd := []byte(cleanedDirectory)
				bp := []byte(cleanedPath)
				bs := string(bp[len(bd):len(bp)])

				p.File = "." + bs
				p.Absolute = cleanedPath
				p.ToDos = findToDos(content)
				//pageData[cleanedPath] = pageData

				pageDataList = append(pageDataList, p)

			}

			return nil
		})

	return err, pageDataList
}

func importData(content []byte) (error, pageData) {

	data := pageData{}

	s := string(content)
	a := strings.Index(s, "\n---")
	if a == -1 {
		return errors.New("the file does not contain a definition block"), pageData{}
	}
	s = s[a+4 : len(s)-1]
	b := strings.Index(s, "\n...")

	if b == -1 {
		b = strings.Index(s, "\n---")
	}

	if b > -1 {
		s = s[0:b]
	}

	err := yaml.Unmarshal([]byte(s), &data)

	if err != nil {
		return err, pageData{}
	}

	return nil, data
}
