package main

import (
	"bytes"
	"fmt"
	"time"

	"github.com/olekukonko/tablewriter"
)

type Item struct {
	Group         string    `yaml:"Group"`
	Description   string    `yaml:"Description"`
	DeliveryUntil time.Time `yaml:"Delivery until"`
	providedOn    time.Time `yaml:"Provided on"`
	providedBy    string    `yaml:"Provided by"`
}

func buildItemTable(config *Configuration, pageDataList []pageData) (error, string) {

	buf := new(bytes.Buffer)

	table := tablewriter.NewWriter(buf)

	table.SetHeader([]string{"Group", "Description", "Delivery until", "Provided on", "Provided by", "File"})
	table.SetBorders(tablewriter.Border{Left: true, Top: false, Right: true, Bottom: false})
	table.SetCenterSeparator("|")

	var tableData [][]string

	for _, pageData := range pageDataList {
		for _, info := range pageData.Items {

			var db, do string

			if info.DeliveryUntil.IsZero() {
				db = "—"
			} else {
				db = info.DeliveryUntil.Format(config.Locale.DateFormat)
			}
			if info.providedOn.IsZero() {
				db = "—"
			} else {
				db = info.providedOn.Format(config.Locale.DateFormat)
			}

			tableData = append(tableData, []string{info.Group, info.Description, db, do, info.providedBy, pageData.File})
		}

	}

	table.AppendBulk(tableData) // Add Bulk Data
	table.SetHeaderAlignment(tablewriter.ALIGN_LEFT)
	table.Render()

	return nil, buf.String()
}

func printItemTable(config *Configuration) error {
	err, pageData := GetPageData(config.Path)
	if err != nil {
		return err
	}

	err, table := buildItemTable(config, pageData)
	fmt.Println(table)

	return nil
}
